@@ -744,7 +744,7 @@ public class MetaDataFieldSkeleton extends Composite{
 
 		FieldAsTag asTag = field.getAsTag();
 		List<String> generatedTags = new ArrayList<String>();
-		if(asTag != null){
+		if(asTag != null && asTag.isCreate()){
 			List<String> values = getFieldCurrentValue();
 			for (String value : values) {
 				generatedTags.add(TaggingGroupingValue.getComposedValueTag(field.getFieldName(), value, asTag.getSeparator(), asTag.getTaggingValue()));
